# Table of Contents

- [propagating-business-context-relations-to-parent-applications-relation-inheritance](<./propagating-business-context-relations-to-parent-applications-relation-inheritance.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Propagating Business Context Relations to Parent Applications (Relation Inheritance)](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance.md>)
  - [Overview](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Overview.md>)
  - [Prerequisites](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Prerequisites.md>)
  - [Automation Logic](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Automation-Logic.md>)
  - [How It Works: Example](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/How-It-Works-Example.md>)
  - [Technical Details](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Technical-Details.md>)
  - [Configuration](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Configuration.md>)
  - [Automation 1: Relation Is Added (Business Context to Child)](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Automation-1-Relation-Is-Added-Business-Context-to-Child.md>)
  - [Automation 2: Relation Is Removed (Business Context from Child)](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Automation-2-Relation-Is-Removed-Business-Context-from-Child.md>)
  - [Automation 3: Child Unlinked from Parent (Parent Side)](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Automation-3-Child-Unlinked-from-Parent-Parent-Side.md>)
  - [Automation 4: Child Removes Parent Relation (Catch-All)](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Automation-4-Child-Removes-Parent-Relation-Catch-All.md>)
  - [Validation](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Validation.md>)
  - [Was this page helpful?](<./Propagating-Business-Context-Relations-to-Parent-Applications-Relation-Inheritance/Was-this-page-helpful.md>)
